@@ -1,6 +1,8 @@
 import json
 from datetime import datetime, timezone
 
+from pyzil.account import Account
+
 
 def to_int(val):
     if val is None:
@@ -20,6 +22,18 @@ def iso_datetime_string(timestamp):
     return datetime.utcfromtimestamp(timestamp / 1000000).strftime('%Y-%m-%d %H:%M:%S')
 
 
+def encode_bench32_pub_key(pub_key):
+    if pub_key is None:
+        return None
+    return Account(public_key=pub_key).bech32_address
+
+
+def encode_bench32_address(address):
+    if address is None:
+        return None
+    return Account(address=address).bech32_address
+
+
 def json_dumps(obj):
     if obj is None:
         return None
